pytroll-aapp-runner
===================

[![Build status](https://github.com/pytroll/pytroll-aapp-runner/workflows/CI/badge.svg?branch=main)](https://github.com/pytroll/pytroll-aapp-runner/workflows/CI/badge.svg?branch=main)
[![Coverage Status](https://coveralls.io/repos/github/pytroll/pytroll-aapp-runner/badge.svg?branch=main)](https://coveralls.io/github/pytroll/pytroll-aapp-runner?branch=main)


A pytroll runner supporting real-time processing of Direct Readout or regional
(RARS type) AVHRR and ATOVS data from level-0 to level-1 using the NWPSAF/AAPP
package.